@@ -13,15 +13,17 @@ class Dataset(object):
                         For instance, [<class 'RandomCrop'>, <class 'Rotate'>]
         '''
         with open(annotation_file) as f:
-            self.data = json.load(f)
-        print(self.data)
+            lines = f.readlines()
+            self.data = []
+            for line in lines:
+                self.data.append(json.loads(line))
         
 
     def __len__(self):
         '''
             return the number of data points in the dataset
         '''
-
+        return len(self.data)
         
 
     def __getitem__(self, idx):
@@ -47,4 +49,4 @@ class Dataset(object):
             5. Return the transformed image and annotations as specified.
         '''
 
-Dataset('../../../data/annotations.jsonl')
\ No newline at end of file
+        
\ No newline at end of file
